@@ -29,6 +29,7 @@ MainWindow::MainWindow(QWidget *parent) :
     labelBox.setFixedHeight(50);
     labelBox.setAlignment(Qt::AlignCenter);
     infoBox.setWidget(&labelBox);
+    ui->lyricsWebViewButton->setFont(QFont("Nokia Sans", 12));
 
     nam = new QNetworkAccessManager(this);
     connect(nam, SIGNAL(finished(QNetworkReply*)), this, SLOT(onRequestFinished(QNetworkReply*)));
@@ -37,6 +38,9 @@ MainWindow::MainWindow(QWidget *parent) :
     connectBluetoothControl();
     new TextEditAutoResizer(ui->cronologyTextEdit);
 
+    //setAttribute(Qt::WA_Maemo5StackedWindow);
+    //setWindowFlags(Qt::Window);
+
     qDebug()<<time.elapsed();
 }
 
@@ -255,7 +259,7 @@ void MainWindow::on_stopButton_clicked()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About"),
-                        tr("<h2>Internet Radio Player 0.0.7</h2>"
+                        tr("<h2>Internet Radio Player 0.0.8</h2>"
                            "<p>"
                            "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"
                            "<p><a href=\"http://code-tinkering.blogspot.com/\">My personal blog.</a>"
@@ -589,3 +593,20 @@ void MainWindow::toggleButtonPressed()
 
 
 
+
+void MainWindow::on_lyricsWebViewButton_clicked()
+{
+    QString artist = ui->artistLineEdit->text();
+    QString title = ui->titleLineEdit->text();
+    QString windowTitle = QString("%1 - %2").arg(artist, title);
+    qDebug()<<"1";
+    artist.replace(' ', '-');
+    title.replace(' ', '-');
+    qDebug()<<"String:"<<artist<<"    "<<title;
+    QString url = QString("http://www.lyrics.com/%1-lyrics-%2.html").arg(title).arg(artist);
+    qDebug()<<"Url: "<<url;
+    lyricsWebView = new LyricsWebView(this);
+    lyricsWebView->setUrl(url);
+    lyricsWebView->setWindowTitle(windowTitle);
+    lyricsWebView->show();
+}
