@@ -5,6 +5,7 @@
 #include "bluetoothheadsetadapter.h"
 #include "stationsdb.h"
 #include "filterlistbydialog.h"
+#include "lyricswebview.h"
 
 #include <QBuffer>
 #include <QClipboard>
@@ -15,6 +16,7 @@
 #include <QInputDialog>
 #include <QLabel>
 #include <QListWidgetItem>
+#include <QtMaemo5>
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <QtMultimediaKit/QMediaPlayer>
 #include <QMessageBox>
@@ -66,6 +68,7 @@ private slots:
     void on_actionFilterListByCountry_triggered();
     void on_actionDoNotFilter_triggered();
     void toggleButtonPressed();
+    void on_lyricsWebViewButton_clicked();
 
 private:
     Ui::MainWindow *ui;
@@ -77,6 +80,8 @@ private:
     StationsDB stationsDb;
     BluetoothHeadsetAdapter bluetoothAdapter;
 
+    LyricsWebView* lyricsWebView;
+
     QNetworkAccessManager *nam;
     int imageRequest;
     QByteArray bytes;
